@@ -16,8 +16,13 @@ board_initialize.rsconnect <- function(board, ...) {
     args$key <- envvar_key
   }
 
+  envvar_server <- Sys.getenv("RSCONNECT_SERVER")
+  if (is.null(args$server) && nchar(envvar_server) > 0) {
+    args$server <- envvar_server
+  }
+
   board$server <- args$server
-  board$server_name <- if (!is.null(args$server)) gsub("https?://|:[0-9]+/?", "", args$server) else NULL
+  board$server_name <- if (!is.null(args$server)) gsub("https?://|:[0-9]+/?|/.*", "", args$server) else NULL
   board$account <- args$account
   board$output_files <- args$output_files
 
@@ -141,15 +146,16 @@ board_pin_create.rsconnect <- function(board, path, name, metadata, ...) {
     if (!is.null(result$error)) {
       stop("Failed to activate pin: ", result$error)
     }
+
+    # it might take a few seconds for the pin to register in rsc, see travis failures, wait 5s
+    rsconnect_wait_by_name(board, name)
   }
 }
 
-board_pin_find.rsconnect <- function(board, text, ...) {
-  all_content  <- identical(list(...)$all_content, TRUE)
-
+board_pin_find.rsconnect <- function(board, text = NULL, all_content = FALSE, name = NULL, ...) {
   if (is.null(text)) text <- ""
 
-  if (nchar(text) == 0) {
+  if (nchar(text) == 0 && is.null(name)) {
     # it can be quite slow to list all content in RStudio Connect so we scope to the user content
     account_id <- rsconnect_api_get(board, "/__api__/users/current/")$id
     filter <- paste0("filter=account_id:", account_id, "&accountId:", account_id)
@@ -161,9 +167,11 @@ board_pin_find.rsconnect <- function(board, text, ...) {
   entries <- rsconnect_api_get(board, paste0("/__api__/applications/?", utils::URLencode(filter)))$applications
   if (!all_content) entries <- Filter(function(e) e$content_category == "pin", entries)
 
-  results <- pin_results_from_rows(entries)
+  entries <- lapply(entries, function(e) { e$name <- paste(e$owner_username, e$name, sep = "/") ; e })
 
-  results$name <- sapply(entries, function(e) paste(e$owner_username, e$name, sep = "/"))
+  if (!is.null(name)) entries <- Filter(function(e) grepl(name, e$name), entries)
+
+  results <- pin_results_from_rows(entries)
 
   if (nrow(results) == 0) {
     return(
@@ -177,7 +185,7 @@ board_pin_find.rsconnect <- function(board, text, ...) {
   results$metadata <- sapply(results$description, function(e) as.character(jsonlite::toJSON(board_metadata_from_text(e), auto_unbox = TRUE)))
   results$description <- board_metadata_remove(results$description)
 
-  if (nrow(results) == 1) {
+  if (length(entries) == 1) {
     # enhance with pin information
     remote_path <- rsconnect_remote_path_from_url(entries[[1]]$url)
     etag <- as.character(entries[[1]]$last_deployed_time)
@@ -195,15 +203,15 @@ board_pin_find.rsconnect <- function(board, text, ...) {
 }
 
 rsconnect_get_by_name <- function(board, name) {
-  name_pattern <- if (grepl("/", name)) name else paste0(".*/", name, "$")
+  name_pattern <- if (grepl("/", name)) paste0("^", name, "$") else paste0(".*/", name, "$")
   only_name <- pin_content_name(name)
 
-  details <- board_pin_find(board, only_name)
+  details <- board_pin_find(board, name = name_pattern)
   details <- pin_results_extract_column(details, "content_category")
   details <- pin_results_extract_column(details, "url")
   details <- pin_results_extract_column(details, "guid")
 
-  details <- details[grepl(name_pattern, details$name) & details$content_category == "pin",]
+  details <- details[grepl(name_pattern, details$name),]
 
   if (nrow(details) > 1) {
     details <- details[details$owner_username == board$account,]
@@ -216,6 +224,14 @@ rsconnect_get_by_name <- function(board, name) {
   details
 }
 
+rsconnect_wait_by_name <- function(board, name) {
+  wait_time <- 0
+  while (nrow(rsconnect_get_by_name(board, name)) == 0 && wait_time < getOption("pins.rsconnect.wait", 5)) {
+    Sys.sleep(1)
+    wait_time <- wait_time + 1
+  }
+}
+
 rsconnect_remote_path_from_url <- function(url) {
   url <- gsub("/$", "", url)
   gsub("//", "/", file.path("/content", gsub("(^.*/|^)content/", "", url)))
